client

package
v0.0.0-...-01c6c21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package client contains helper functions to configure the microcluster

Index

Constants

const (
	// ClusterCA is the key for the cluster CA configuration.
	ClusterCA = "cluster-ca"
)

Variables

This section is empty.

Functions

func ConfigClusterCAGet

func ConfigClusterCAGet(ctx context.Context, c *microCli.Client) (string, error)

ConfigClusterCAGet fetches the cluster ca.

func ConfigClusterCASet

func ConfigClusterCASet(ctx context.Context, c *microCli.Client, data string) error

ConfigClusterCASet configures the cluster ca. This CA is used to validate incoming queries to extended endpoints.

Types

This section is empty.

Jump to